@@ -11,7 +11,7 @@ use File::MoreUtil qw(file_exists l_abs_path);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-07-29'; # DATE
 our $DIST = 'File-Trash-FreeDesktop'; # DIST
-our $VERSION = '0.202'; # VERSION
+our $VERSION = '0.203'; # VERSION
 
 sub new {
     require File::HomeDir::FreeDesktop;
@@ -190,7 +190,7 @@ sub list_contents {
                 if (defined $opts->{path_wildcard}) {
                     unless (defined $path_wc_re) {
                         require String::Wildcard::Bash;
-                        $path_wc_re = String::Wildcard::Bash::convert_wildcard_to_re($opts->{path_wildcard});
+                        $path_wc_re = String::Wildcard::Bash::convert_wildcard_to_re({globstar=>1}, $opts->{path_wildcard});
                     }
                     next ENTRY unless $parse_res->{path} =~ $path_wc_re;
                 }
@@ -205,7 +205,7 @@ sub list_contents {
                     if (defined $opts->{filename_wildcard}) {
                         unless (defined $filename_wc_re) {
                             require String::Wildcard::Bash;
-                            $filename_wc_re = String::Wildcard::Bash::convert_wildcard_to_re($opts->{filename_wildcard});
+                            $filename_wc_re = String::Wildcard::Bash::convert_wildcard_to_re({globstar=>1}, $opts->{filename_wildcard});
                         }
                         next ENTRY unless $filename =~ $filename_wc_re;
                     }
@@ -384,7 +384,7 @@ File::Trash::FreeDesktop - Trash files
 
 =head1 VERSION
 
-This document describes version 0.202 of File::Trash::FreeDesktop (from Perl distribution File-Trash-FreeDesktop), released on 2023-07-29.
+This document describes version 0.203 of File::Trash::FreeDesktop (from Perl distribution File-Trash-FreeDesktop), released on 2023-07-29.
 
 =head1 SYNOPSIS
 
